#  igi commands
#  Order must match dictionary in cmdict.h

define	ANGLE		1
define	APROPOS		2
define	AXIS		3
define	BOX		4
define	BYE		5
define	CONNECT		6
define	CURSES		7
define	DATA		8
define	DDRAW		9
define	DEFINE		10
define	DELETE		11
define	DLIST		12
define	DMOVE		13
define	DOT		14
define	DRAW		15
define	DRELOCATE	16
define	ECOLUMN		17
define	EDITCMD		18
define	EEVALUATE	19
define	ELLIPSE		20
define	END		21
define	ERASE		22
define	ERRORBAR	23
define	ESCAPE		24
define	ETYPE		25
define	EXPAND		26
define	GRID		27
define	HELP		28
define	HISTOGRAM	29
define	ID		30
define	INPUT		31
define	JUSTIFY		32
define	LABEL		33
define	LCOLUMN		34
define	LEVALUATE	35
define	LIMITS		36
define	LINES		37
define	LIST		38
define	LOCATION	39
define	LOGO		40
define	LTYPE		41
define	LWEIGHT		42
define	MACROS		43
define	MENU		44
define	MINMAX		45
define	MODE		46
define	MOVE		47
define	NOOP		48
define	NOTATION	49
define	PAGECMD		50
define	PCOLUMN		51
define	PEVALUATE	52
define	PHYSICAL	53
define	PLAYBACK	54
define	POINTS		55
define	PREVIOUS	56
define	PTYPE		57
define	PUTLABEL	58
define	READ		59
define	RELOCATE	60
define	RESET		61
define	SCOLUMN		62
define	SEVALUATE	63
define	SHOW		64
define	STEP		65
define	TICKSIZE	66
define	TITLE		67
define	ULLIM		68
define	UNDO		69
define	UNSET		70
define	VDRAW		71
define	VMOVE		72
define	VPAGE		73
define	VRELOCATE	74
define	WINDOW		75
define	WRITE		76
define	XCOLUMN		77
define	XEVALUATE	78
define	XFLIP		79
define	XLABEL		80
define	XLOGARITHM	81
define	XSIXTY		82
define	YCOLUMN		83
define	YEVALUATE	84
define	YFLIP		85
define	YLABEL		86
define	YLOGARITHM	87
define	YSIXTY		88
define	XSECTION	89
define	YSECTION	90
define	ESECTION	91
define	PSECTION	92
define	LSECTION	93
define	SSECTION	94
define	MARGIN		95
define	IMGWCS		96
define	FMTICK		97
define	COLOR		98	# 5/92
define	NUMBER		99
define	FONTSET		100	# 6/92
define	ZSECTION	101	# 6/22/92
define	PIXMAP		102
define	FITPIX		103	# 6/24/92
define	CMAPLUT		104
define	ZRANGE		105	# 6/25/92
define	PDRAW		106	# 7/9/92
define	PMOVE		107
define	PRELOCATE	108
define	ZEVALUATE	109
define	FILLPAT		110	# 7/17/92
define	ATTRIB		111
define	BARGRAPH	112	# 7/21/92
define	SAOCMAP		113	# 7/24/92
define	WCSLAB		114	# 7/2/93
define	VERSION		115	# 7/13/93
define	POLYGON		116
define	PSFONT		117	# 5/20/97
define	PSCMD		118	# 11/15/99
