# COMMAND.H -- Commands which can be executed from the prompt line

define	TED_CMDLIST  "|add|copy|delete|exit|find|goto|help|insert|lower|next|\
quit|set|substitute|upper|"

define	TED_ADD		1
define	TED_COPY	2
define	TED_DELETE	3
define	TED_EXIT	4
define	TED_FIND	5
define	TED_GOTO	6
define	TED_HELP	7
define	TED_INSERT	8
define	TED_LOWER	9
define	TED_NEXT	10
define	TED_QUIT	11
define	TED_SET		12
define	TED_SUBSTITUTE	13
define	TED_UPPER	14


