/* This file is used by tbfxff.c. */

# if defined(NO_UNDERSCORE)
# define FTDREC_U ftdrec
# define FTCMSG_U ftcmsg
# define FSGIOU_U fsgiou
# define FSFIOU_U fsfiou
# define FSCLOS_U fsclos
# define FSCOPY_U fscopy
# define FSCRHD_U fscrhd
# define FSDHDU_U fsdhdu
# define FSDROW_U fsdrow
# define FSGTBB_U fsgtbb
# define FSPTBB_U fsptbb
# define FSFIOU_U fsfiou
# define FSGCL_U  fsgcl 
# define FSGCFL_U fsgcfl
# define FSGCVD_U fsgcvd
# define FSGCVE_U fsgcve
# define FSGCVI_U fsgcvi
# define FSGCVJ_U fsgcvj
# define FSGCVS_U fsgcvs
# define FSGHSP_U fsghsp
# define FSGIOU_U fsgiou
# define FSGKEY_U fsgkey
# define FSGKYD_U fsgkyd
# define FSGKYJ_U fsgkyj
# define FSGKYS_U fsgkys
# define FSGMSG_U fsgmsg
# define FSGREC_U fsgrec
# define FSGRSZ_U fsgrsz
# define FSGTDM_U fsgtdm
# define FSIBIN_U fsibin
# define FSICOL_U fsicol
# define FSINIT_U fsinit
# define FSIROW_U fsirow
# define FSMAHD_U fsmahd
# define FSMCOM_U fsmcom
# define FSMKYD_U fsmkyd
# define FSMKYE_U fsmkye
# define FSMKYJ_U fsmkyj
# define FSMKYL_U fsmkyl
# define FSMKYS_U fsmkys
# define FSMREC_U fsmrec
# define FSOPEN_U fsopen
# define FSPCLD_U fspcld
# define FSPCLE_U fspcle
# define FSPCLI_U fspcli
# define FSPCLJ_U fspclj
# define FSPCLL_U fspcll
# define FSPCLS_U fspcls
# define FSPCLU_U fspclu
# define FSPCOM_U fspcom
# define FSPHBN_U fsphbn
# define FSPHIS_U fsphis
# define FSPHPR_U fsphpr
# define FSPKYD_U fspkyd
# define FSPKYE_U fspkye
# define FSPKYJ_U fspkyj
# define FSPKYL_U fspkyl
# define FSPKYS_U fspkys
# define FSPREC_U fsprec
# define FSPSVC_U fspsvc
# define FSPTDM_U fsptdm
# define FSRDEF_U fsrdef
# define FSUKYD_U fsukyd
# define FSUKYJ_U fsukyj
# define FSUKYL_U fsukyl
# define FSUKYS_U fsukys
# else
# define FTDREC_U ftdrec_
# define FTCMSG_U ftcmsg_
# define FSGIOU_U fsgiou_
# define FSFIOU_U fsfiou_
# define FSCLOS_U fsclos_
# define FSCOPY_U fscopy_
# define FSCRHD_U fscrhd_
# define FSDHDU_U fsdhdu_
# define FSDROW_U fsdrow_
# define FSGTBB_U fsgtbb_
# define FSPTBB_U fsptbb_
# define FSFIOU_U fsfiou_
# define FSGCL_U  fsgcl_
# define FSGCFL_U fsgcfl_
# define FSGCVD_U fsgcvd_
# define FSGCVE_U fsgcve_
# define FSGCVI_U fsgcvi_
# define FSGCVJ_U fsgcvj_
# define FSGCVS_U fsgcvs_
# define FSGHSP_U fsghsp_
# define FSGIOU_U fsgiou_
# define FSGKEY_U fsgkey_
# define FSGKYD_U fsgkyd_
# define FSGKYJ_U fsgkyj_
# define FSGKYS_U fsgkys_
# define FSGMSG_U fsgmsg_
# define FSGREC_U fsgrec_
# define FSGRSZ_U fsgrsz_
# define FSGTDM_U fsgtdm_
# define FSIBIN_U fsibin_
# define FSICOL_U fsicol_
# define FSINIT_U fsinit_
# define FSIROW_U fsirow_
# define FSMAHD_U fsmahd_
# define FSMCOM_U fsmcom_
# define FSMKYD_U fsmkyd_
# define FSMKYE_U fsmkye_
# define FSMKYJ_U fsmkyj_
# define FSMKYL_U fsmkyl_
# define FSMKYS_U fsmkys_
# define FSMREC_U fsmrec_
# define FSOPEN_U fsopen_
# define FSPCLD_U fspcld_
# define FSPCLE_U fspcle_
# define FSPCLI_U fspcli_
# define FSPCLJ_U fspclj_
# define FSPCLL_U fspcll_
# define FSPCLS_U fspcls_
# define FSPCLU_U fspclu_
# define FSPCOM_U fspcom_
# define FSPHBN_U fsphbn_
# define FSPHIS_U fsphis_
# define FSPHPR_U fsphpr_
# define FSPKYD_U fspkyd_
# define FSPKYE_U fspkye_
# define FSPKYJ_U fspkyj_
# define FSPKYL_U fspkyl_
# define FSPKYS_U fspkys_
# define FSPREC_U fsprec_
# define FSPSVC_U fspsvc_
# define FSPTDM_U fsptdm_
# define FSRDEF_U fsrdef_
# define FSUKYD_U fsukyd_
# define FSUKYJ_U fsukyj_
# define FSUKYL_U fsukyl_
# define FSUKYS_U fsukys_
# endif
