#  This file contains the global defines for the IRAF/SPP version of FITSIO.
#  (This is not a C header file)
#  SZ_FTTYPE, SZ_FTFORM, and SZ_FTUNIT were changed on 1999 Mar 10 by PEH

define	SZ_FERRTXT	30	# length of FITSIO error message
define	SZ_FKEYWORD	8	# length of keyword name string
define	SZ_FSTRVAL	70	# length of keyword value string
define	SZ_FCOMMENT	48	# length of keyword comment string
define	SZ_FLONGCOMM	72	# length of long keyword comment
define	SZ_FCARD	80	# length of 'card' record
define	SZ_FTTYPE	70	# length of column name string
define	SZ_FTFORM	70	# len of col datatype and display format strings
define	SZ_FTUNIT	70	# length of column units string
define	SZ_FEXTNAME	24	# length of extension name string
define  SZ_FTNULL       16      # length of null value string
