# igi command dictionary
# Order must match macros in commands.h

string	cmdict "|\
ANGLE|APROPOS|AXIS|\
BOX|BYE|\
CONNECT|CURSES|\
DATA|DDRAW|DEFINE|DELETE|DLIST|DMOVE|DOT|DRAW|DRELOCATE|\
ECOLUMN|EDITCMD|EEVALUATE|ELLIPSE|END|ERASE|ERRORBAR|ESCAPE|ETYPE|EXPAND|\
GRID|\
HELP|HISTOGRAM|\
ID|INPUT|\
JUSTIFY|\
LABEL|LCOLUMN|LEVALUATE|LIMITS|LINES|LIST|LOCATION|LOGO|LTYPE|LWEIGHT|\
MACROS|MENU|MINMAX|MODE|MOVE|\
NOOP|NOTATION|\
PAGECMD|PCOLUMN|PEVALUATE|PHYSICAL|PLAYBACK|POINTS|PREVIOUS|PTYPE|PUTLABEL|\
READ|RELOCATE|RESET|\
SCOLUMN|SEVALUATE|SHOW|STEP|\
TICKSIZE|TITLE|\
ULLIM|UNDO|UNSET|\
VDRAW|VMOVE|VPAGE|VRELOCATE|\
WINDOW|WRITE|\
XCOLUMN|XEVALUATE|XFLIP|XLABEL|XLOGARITHM|XSIXTY|\
YCOLUMN|YEVALUATE|YFLIP|YLABEL|YLOGARITHM|YSIXTY|\
XSECTION|YSECTION|ESECTION|PSECTION|LSECTION|SSECTION|\
MARGIN|IMGWCS|FMTICK|\
COLOR|NUMBER|\
FONTSET|\
ZSECTION|PIXMAP|FITPIX|CMAPLUT|ZRANGE|\
PDRAW|PMOVE|PRELOCATE|\
ZEVALUATE|\
FILLPAT|\
ATTRIB|\
BARGRAPH|\
SAOCMAP|\
WCSLAB|\
VERSION|\
POLYGON|\
PSFONT|\
PSCMD|\
"
